import { Emitter } from 'mitt';
import { default as SuprSend } from './main';
import { IFeedOptions, IInboxFetchOptions, InboxEmitterEvents, ApiResponse, IFeedData } from './interface';

export default class FeedsFactory {
    private config;
    feedInstances: Feed[];
    constructor(config: SuprSend);
    initialize(options?: IFeedOptions): Feed;
    removeInstance(feedClient: Feed): void;
    removeAll(): void;
}
export declare class Feed {
    feedOptions: IFeedOptions;
    private config;
    private store;
    private socket;
    private expiryTimerId?;
    readonly emitter: Emitter<InboxEmitterEvents>;
    constructor(config: SuprSend, options: IFeedOptions);
    private setOptions;
    private validateStore;
    private createFeedStore;
    private initializeSocketEvents;
    private handleNewNotificationSocketEvent;
    private handleNoticationUpdateSocketEvent;
    private handleBulkNotificationUpdateSocketEvent;
    private notificationBelongToStore;
    private orderNotificationsBasedOnPinFlag;
    private startExpiryTimer;
    private removeExpiredFeed;
    private getUrl;
    private validateQueryParams;
    private requestInprogress;
    private storesQueryParamObj;
    private storeQueryParamObj;
    changeActiveStore(storeId: string): Promise<ApiResponse | undefined>;
    get data(): IFeedData;
    initializeSocketConnection(): void;
    fetch(options?: IInboxFetchOptions): Promise<ApiResponse | undefined>;
    fetchNextPage(): Promise<ApiResponse | undefined>;
    fetchCount(): Promise<ApiResponse>;
    fetchDetails(notificationId: string): Promise<ApiResponse>;
    markAsSeen(notificationId: string): Promise<ApiResponse>;
    markAsRead(notificationId: string): Promise<ApiResponse>;
    markAsUnread(notificationId: string): Promise<ApiResponse>;
    markAsInteracted(notificationId: string): Promise<ApiResponse>;
    markAsArchived(notificationId: string): Promise<ApiResponse>;
    markBulkAsSeen(notificationIds: string[]): Promise<ApiResponse>;
    resetBadgeCount(): Promise<ApiResponse>;
    markAllAsRead(): Promise<ApiResponse>;
    reset(): void;
    remove(): void;
}
