import { default as SuprSend } from './main';
import { Dictionary, PreferenceData, PreferenceOptions, ChannelLevelPreferenceOptions } from './interface';

export default class Preferences {
    private config;
    private preferenceData;
    private preferenceArgs?;
    private debouncedUpdateCategoryPreferences;
    private debouncedUpdateChannelPreferences;
    private debounceTime;
    constructor(config: SuprSend);
    private validateQueryParams;
    set data(value: PreferenceData);
    get data(): PreferenceData;
    getUrl(path: string, qp?: Dictionary): string;
    /**
     * Used to get user's whole preferences data.
     */
    getPreferences(args?: {
        tenantId?: string;
        showOptOutChannels?: boolean;
        tags?: string | Dictionary;
    }): Promise<import('./interface').ApiResponse>;
    /**
     * Used to get user's preference of all categories.
     */
    getCategories(args?: {
        tenantId?: string;
        showOptOutChannels?: boolean;
        tags?: string | Dictionary;
        limit?: number;
        offset?: number;
    }): Promise<import('./interface').ApiResponse>;
    /**
     * Used to get user's preference of specific category.
     */
    getCategory(category: string, args?: {
        tenantId?: string;
        showOptOutChannels?: boolean;
    }): Promise<import('./interface').ApiResponse>;
    /**
     * Used to get user's all channel level preference.
     */
    getOverallChannelPreferences(): Promise<import('./interface').ApiResponse>;
    private _updateCategoryPreferences;
    private _updateChannelPreferences;
    /**
     * Used to update user's category level preference.
     */
    updateCategoryPreference(category: string, preference: PreferenceOptions, args?: {
        tenantId?: string;
        showOptOutChannels?: boolean;
        tags?: string | Dictionary;
    }): Promise<import('./interface').ApiResponse>;
    /**
     * Used to update user's category level channel preference.
     */
    updateChannelPreferenceInCategory(channel: string, preference: PreferenceOptions, category: string, args?: {
        tenantId?: string;
        showOptOutChannels?: boolean;
        tags?: string | Dictionary;
    }): Promise<import('./interface').ApiResponse>;
    /**
     * Used to update user's channel level preference.
     */
    updateOverallChannelPreference(channel: string, preference: ChannelLevelPreferenceOptions): Promise<import('./interface').ApiResponse>;
}
