import { SuprSend } from './index';
import { Dictionary } from './interface';
import { default as Preferences } from './preferences';

export default class User {
    private config;
    preferences: Preferences;
    constructor(config: SuprSend);
    private isReservedKey;
    private formatParamsToObj;
    private formatParamsToArray;
    private validateObjData;
    private validateArrayData;
    private triggerUserEvent;
    /**
     * Used to set user properties. Keys with $ and ss_ will be removed.
     */
    set(arg1: string | Dictionary, arg2?: unknown): Promise<import('./interface').ApiResponse>;
    /**
     * Used to set user properties only once. Properties once set cannot be changed later.
     * Keys with $ and ss_ will be removed.
     */
    setOnce(arg1: string | Dictionary, arg2?: unknown): Promise<import('./interface').ApiResponse>;
    /**
     * Used to increment/decrement user properties whose values are numbers. To decrement use -ve values.
     * Keys with $ and ss_ will be removed.
     */
    increment(arg1: string | Dictionary, arg2?: number): Promise<import('./interface').ApiResponse>;
    /**
     * Used to add items to list if user property is list (example: wishlist: [iphone, macbook]).
     * Keys with $ and ss_ will be removed.
     */
    append(arg1: string | Dictionary, arg2?: unknown): Promise<import('./interface').ApiResponse>;
    /**
     * Used to remove items from list if user property is list.
     * Keys with $ and ss_ will be removed.
     */
    remove(arg1: string | Dictionary, arg2?: unknown): Promise<import('./interface').ApiResponse>;
    /**
     * Used to remove user property. Keys with $ and ss_ will be removed.
     */
    unset(arg: string | string[]): Promise<import('./interface').ApiResponse>;
    private appendInternal;
    private removeInternal;
    private setInternal;
    private validateEmail;
    private validateMobile;
    addEmail(email: string): Promise<import('./interface').ApiResponse>;
    removeEmail(email: string): Promise<import('./interface').ApiResponse>;
    /**
     * Mobile number must be as per {@link https://www.twilio.com/docs/glossary/what-e164 E.164 standard}.
     */
    addSms(mobile: string): Promise<import('./interface').ApiResponse>;
    /**
     * Mobile number must be as per {@link https://www.twilio.com/docs/glossary/what-e164 E.164 standard}.
     */
    removeSms(mobile: string): Promise<import('./interface').ApiResponse>;
    /**
     * Mobile number must be as per {@link https://www.twilio.com/docs/glossary/what-e164 E.164 standard}.
     */
    addWhatsapp(mobile: string): Promise<import('./interface').ApiResponse>;
    /**
     * Mobile number must be as per {@link https://www.twilio.com/docs/glossary/what-e164 E.164 standard}.
     */
    removeWhatsapp(mobile: string): Promise<import('./interface').ApiResponse>;
    private getDeviceId;
    addWebPush(push: PushSubscription): Promise<import('./interface').ApiResponse>;
    removeWebPush(push: PushSubscription): Promise<import('./interface').ApiResponse>;
    addSlack(data: Dictionary): Promise<import('./interface').ApiResponse>;
    removeSlack(data: Dictionary): Promise<import('./interface').ApiResponse>;
    addMSTeams(data: Dictionary): Promise<import('./interface').ApiResponse>;
    removeMSTeams(data: Dictionary): Promise<import('./interface').ApiResponse>;
    /**
     * language passed should be 2-letter language code in {@link https://gist.github.com/jrnk/8eb57b065ea0b098d571 ISO 639-1 Alpha-2 format}.
     * e.g. en (for English), es (for Spanish), fr (for French) etc.
     */
    setPreferredLanguage(language: string): Promise<import('./interface').ApiResponse>;
    /**
     * Timezone passed should be in {@link https://timeapi.io/documentation/iana-timezones IANA timezone format}.
     */
    setTimezone(timezone: string): Promise<import('./interface').ApiResponse>;
}
